from .run import build_package

if __name__ == "__main__":
    build_package()
